Anyone is free to contribute to or fork xFrame

**Did you find a bug?**
- Please create an issue on github.
- Alternatively: open a new github pull request with a patch

**Do you want to utilize part of this code in a bigger project ?**
- You are free to use any part of of this codebase as outlined in the lisence. 
- Please cite the xFrame if you found it useful.

**Other ideas for how to improve xFrame?**
- Create an issue on github or a pull request
